<template>
  <div class="flex-shrink-0 shadow-xl w-14 bg-white overflow-hidden rounded-xl h-full">
    <div class="relative items-center justify-center flex flex-col gap-0">
      <div
          v-for="item in activeItems"
          class="relative w-full flex items-center justify-center aspect-square">
        <button
            @click="handleChangeTab(item.id)"
            :class="`btn btn-circle items-center justify-center btn-ghost p-2 ${general.chatTab === item.id ? 'bg-scheme-primary bg-opacity-20' : ''}`">
          <component :is="item.icon"></component>
        </button>
      </div>
    </div>
  </div>
</template>

<script setup lang="ts">
import {ref, watch} from "vue";
import IconWhatsapp from '../Icon/Icon/IconWhatsapp.vue'
import IconInstagram from '../Icon/Icon/IconInstagram.vue'
import IconMessenger from "../Icon/Icon/IconMessenger.vue";
import IconGoogle from '../Icon/Icon/IconGoogle.vue'
import IconTiktok from '../Icon/Icon/IconTiktok.vue'
import IconEmail from '../Icon/Icon/IconEmail.vue'
import {useGeneralStore} from "../../stores/general";
import {useChatListStore} from "../../stores/chat_list";
import {useUserStore} from "../../stores/user";

const general = useGeneralStore()
const chat = useChatListStore()
const user = useUserStore()

const menuItems = ref([
  {
    icon: IconWhatsapp,
    label: 'Whatsapp',
    id: 'whatsapp',
    default: true,
  },
  {
    icon: IconMessenger,
    label: 'Instagram',
    id: 'instagram',
    default: false,
  }
])

const activeItems = ref([])

// v-if="( ">
const handleChangeTab = (id) => {
  general.isShowProfile = false
  general.chatTab = id
  chat.selectedChat = null
  chat.currentPage = 1
  chat.isEndPage = false
  if(id === 'whatsapp'){
    chat.getUnreadCount()
  }
  else{
    chat.unreadCount.need_fu = 0
  }
  if(id === 'instagram'){
    general.getPremiumInfo().then((resp) => {
      if(resp?.data?.is_premium_package == false){
        general.openDialog("Saat ini anda tidak bisa menggunakan fitur ini.",
        "Silakan hubungi Tim CS Halosis kami!", false, resp?.code, 'instagram')
      }
    }).catch((err) => {
      
    })
  }

  if(id === 'tiktok'){
    general.isShowSync = general.isSync == null ? true : false
  }
}

watch(() => general.chatTab, (val) => {
  chat.fetchChatListByGroup(chat.tabName, true, null, null, val)
})

// watch(() => general.currentPhoneNumber, (val) => {
//   const arr = []
//   menuItems.value.map((item) => {
//     const obj = {}
//     if (item.id !== 'instagram') {
//       arr.push(item)
//     } else {
//       if (general.currentPhoneNumber && (general.currentPhoneNumber?.instagram_id || general.currentPhoneNumber?.page_id)) {
//         arr.push(item)
//       }
//     }
//   })
//   activeItems.value = arr
// })

watch(() => user.listChannel, (val) => {
  const arr = []
  user.listChannel.map((item) => {
    if (item == 'whatsapp') {
      let channel = {
        icon: IconWhatsapp,
        label: 'Whatsapp',
        id: 'whatsapp',
        default: true,
      }
      arr.push(channel)
    }

    if (item == 'instagram') {
      let channel = {
        icon: IconMessenger,
        label: 'Instagram',
        id: 'instagram',
        default: false,
      }
      arr.push(channel)
    }

    if (item == 'email') {
      let channel = {
        icon: IconEmail,
        label: 'Email',
        id: 'email',
        default: false,
      }
      arr.push(channel)
    }
    
    if (item == 'tiktok') {
      let channel = {
        icon: IconTiktok,
        label: 'TikTok',
        id: 'tiktok',
        default: false,
      }
      arr.push(channel)
    }
  })

  activeItems.value = arr
},{ deep: true })
</script>

